# Changelog

## 0.1.4 (2025-12-03)

Full Changelog: [v0.1.3...v0.1.4](https://github.com/et0and/schools-sdk-python/compare/v0.1.3...v0.1.4)

### Bug Fixes

* ensure streams are always closed ([4a636b0](https://github.com/et0and/schools-sdk-python/commit/4a636b04eaf667f6e92a60515379f2af636495d3))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([d2a6052](https://github.com/et0and/schools-sdk-python/commit/d2a60529290a6aec3ec330b485b75693664a108e))
* **docs:** use environment variables for authentication in code snippets ([4ad844e](https://github.com/et0and/schools-sdk-python/commit/4ad844ed51c139f70ed4ff2f6e76ed8e0c28b3e1))
* update lockfile ([60dff69](https://github.com/et0and/schools-sdk-python/commit/60dff690c733085e0fbac043e795dde94a538547))

## 0.1.3 (2025-11-22)

Full Changelog: [v0.1.2...v0.1.3](https://github.com/et0and/schools-sdk-python/compare/v0.1.2...v0.1.3)

### Bug Fixes

* compat with Python 3.14 ([c808edf](https://github.com/et0and/schools-sdk-python/commit/c808edf7d22cd29098f8c81b35b7187e4242fe13))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([c78202e](https://github.com/et0and/schools-sdk-python/commit/c78202e38c569f832de2420791b2f63c55765873))


### Chores

* add Python 3.14 classifier and testing ([c91fd4a](https://github.com/et0and/schools-sdk-python/commit/c91fd4a0a6a8311a1405a24d180e62f09f2e1dbf))
* **package:** drop Python 3.8 support ([71ae8c2](https://github.com/et0and/schools-sdk-python/commit/71ae8c26b917bcbeb244382c7e8f0833a0742c7c))

## 0.1.2 (2025-11-04)

Full Changelog: [v0.1.1...v0.1.2](https://github.com/et0and/schools-sdk-python/compare/v0.1.1...v0.1.2)

### Chores

* update SDK settings ([de8b948](https://github.com/et0and/schools-sdk-python/commit/de8b948666ae96c851e1d75011b4e52ba5935be2))

## 0.1.1 (2025-11-04)

Full Changelog: [v0.0.1...v0.1.1](https://github.com/et0and/schools-sdk-python/compare/v0.0.1...v0.1.1)

### Chores

* configure new SDK language ([0fbcc5f](https://github.com/et0and/schools-sdk-python/commit/0fbcc5fddca8b89445bbe6e8fee11e942957b282))
* update SDK settings ([cbc3fcb](https://github.com/et0and/schools-sdk-python/commit/cbc3fcb8509c0535b526b07b9be6232e2c3e8b5d))
* update SDK settings ([03fe460](https://github.com/et0and/schools-sdk-python/commit/03fe460ff9a8c32e51c92d0f8e2f313c23635f4a))
